//
// This file is part of the Marble Desktop Globe.
//
// This program is free software licensed under the GNU LGPL. You can
// find a copy of this license in LICENSE.txt in the top directory of
// the source code.
//
// Copyright 2012      Konrad Enzensberger / e.konrad@mpegcode.com
//

#ifndef UTMCoordTrans_H
#define UTMCoordTrans_H

/* INCLUDE FILES ***************************************************************/

/* CLASS DECLARATION *************************************************************/
class QString;

class UTMCoordTrans
{
	
public:

	UTMCoordTrans();
	~UTMCoordTrans();

	/* 
	' This Function calculates Easting and Northing in metres from
	'   Lat/Long degrees on a Transverse Mercator projection.
	' EastNorth must be TRUE for "Easting" or FALSE for "Northing" and controls which of these
	' the Function returns.
	' latitude is the latitude in decimal degrees, negative for South.
	' longitude is the longitude in decimal degrees, negative for West.
	' Area is an integer which must be one of the values listed below.
	' Merid is the central meridian of projection, needed only for the UTM options.*/

	double LL2TM(bool EastNorth,double& latitude,double& longitude,long Merid);

	/*
	' This Function calculates UTM Grid Reference
	' from Lat/Long degrees on a Transverse Mercator projection.
	' latitude is the latitude in decimal degrees, negative for South.
	' longitude is the longitude in decimal degrees, negative for West.*/

	bool LL2UTM(double& latitude,double& longitude,QString& pos);

	/*
	' This Function calculates a National or UTM (MGRS) Grid Reference
	' from Lat/Long degrees on a Transverse Mercator projection.
	' latitude is the latitude in decimal degrees, negative for South.
	' longitude is the longitude in decimal degrees, negative for West.
	' Area is an integer which must be one of the values listed below.*/

	bool LL2GR(double& latitude,double& longitude,QString& pos);

	/*Calculates the UTM Longitude Zone number from Latitude/Longitude */
	long UTMLongZone(double latitude,double longitude);

	/*Calculates the UTM Central Meridian from Latitude/Longitude */
	long UTMCM(double latitude,double longitude);

private:

	bool UTMLatZone(double latitude,QString&);
	bool ValidLat(long latitude);
	bool ValidLong(long longitude);
};

#endif //UTMCoordTrans_H
